==> lima-swing-0.4.0-sources.jar: org/chorem/lima/ui/accountsreports/AccountsReportsTableModel.java <==
/*
 * *##% Lima Main
 * Copyright (C) 2008 - 2010 CodeLutin
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>. ##%*
 */

package org.chorem.lima.ui.accountsreports;

import static org.nuiton.i18n.I18n._;
import java.text.SimpleDateFormat;
import javax.swing.table.AbstractTableModel;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.chorem.lima.beans.ReportsDatas;
import org.chorem.lima.entity.Entry;

/**
 * Entry book table model.
 * By : $Author: jpepin $
 */
public class AccountsReportsTableModel extends AbstractTableModel{

    /** serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** log. */
    private static final Log log = LogFactory.getLog(AccountsReportsTableModel.class);
    
    /** data cache */
    protected ReportsDatas cacheDataList;
    

    @Override
    public int getRowCount() {
        int result = 0;
        
        // just prevent too much result
        if (cacheDataList != null) {
        	if (cacheDataList.getListEntry() != null){
                result = cacheDataList.getListEntry().size();
        	}
        }

        return result;
    }

    @Override
    public int getColumnCount() {
        return 8;
    }

    @Override
    public String getColumnName(int column) {
        String res = "n/a";
        switch (column) {
        	case 0:
        		res = _("lima.table.account"); //Account Number
        		break;
            case 1:
                res = _("lima.table.date"); //Date
                break;
            case 2:
                res = _("lima.table.entrybook"); //EntryBook
                break;
            case 3:
                res = _("lima.table.voucher"); // Voucher
                break;
            case 4:
                res = _("lima.table.description"); //Description
                break;
            case 5:
                res = _("lima.table.letter"); //Letter
                break;
            case 6:
                res = _("lima.table.debit"); //Debit
                break;
            case 7:
                res = _("lima.table.credit"); //Credit
                break;
        }
        return res;
    }

    @Override
    public Object getValueAt(int row, int column) {
        Object result = null;
        if(cacheDataList != null) {
            Entry currentRow = cacheDataList.getListEntry().get(row);
            SimpleDateFormat simpleDateFormat
                = new SimpleDateFormat("dd MMMMM yyyy");
            
            switch (column) {
            	case 0:
            		result = currentRow.getAccount().getAccountNumber();
            		break;
                case 1:
                    result = simpleDateFormat.
                            format(currentRow.getFinancialTransaction().getTransactionDate());
                    break;
                case 2:
                    if (currentRow.getFinancialTransaction().getEntryBook() != null){
                        result = currentRow.getFinancialTransaction().getEntryBook().getCode();
                    }
                    else {
                        result = null;
                    }
                    break;
                case 3:
                    result = currentRow.getVoucher();
                    break;
                case 4:
                    result = currentRow.getDescription();
                    break;
                case 5:
                	if (currentRow.getLetter() != null){
                		result = currentRow.getLetter().getCode();
                	}
                	else {
                		result = null;
                	}
                	break;
                case 6:
                    result = currentRow.getDebit() ? currentRow.getAmount() : 0;
                    break;
                case 7:
                    result = currentRow.getDebit() ? 0 : currentRow.getAmount();
                    break;
            }
        } 
        else {
            if (log.isDebugEnabled()) {
                log.debug("No Account selected skip table model update");
            }
        }

        return result;
    }


    @Override
    public boolean isCellEditable(int rowIndex, int columnIndex) {
        // Just read, no write
        return false;
    }
    
    public void refresh(ReportsDatas datasList){
        cacheDataList = datasList;
        fireTableDataChanged();
    }
    
}

==> lima-swing-0.4.1-sources.jar: org/chorem/lima/ui/accountsreports/AccountsReportsTableModel.java <==
/*
 * #%L
 * Lima Swing
 * 
 * $Id: AccountsReportsTableModel.java 3051 2010-11-29 14:57:16Z echatellier $
 * $HeadURL: http://svn.chorem.org/svn/lima/tags/lima-0.4.1/lima-swing/src/main/java/org/chorem/lima/ui/accountsreports/AccountsReportsTableModel.java $
 * %%
 * Copyright (C) 2008 - 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

package org.chorem.lima.ui.accountsreports;

import static org.nuiton.i18n.I18n._;
import java.text.SimpleDateFormat;
import javax.swing.table.AbstractTableModel;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.chorem.lima.beans.ReportsDatas;
import org.chorem.lima.entity.Entry;

/**
 * Entry book table model.
 * By : $Author: echatellier $
 */
public class AccountsReportsTableModel extends AbstractTableModel{

    /** serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** log. */
    private static final Log log = LogFactory.getLog(AccountsReportsTableModel.class);
    
    /** data cache */
    protected ReportsDatas cacheDataList;
    

    @Override
    public int getRowCount() {
        int result = 0;
        
        // just prevent too much result
        if (cacheDataList != null) {
            if (cacheDataList.getListEntry() != null){
                result = cacheDataList.getListEntry().size();
            }
        }

        return result;
    }

    @Override
    public int getColumnCount() {
        return 8;
    }

    @Override
    public String getColumnName(int column) {
        String res = "n/a";
        switch (column) {
            case 0:
                res = _("lima.table.account"); //Account Number
                break;
            case 1:
                res = _("lima.table.date"); //Date
                break;
            case 2:
                res = _("lima.table.entrybook"); //EntryBook
                break;
            case 3:
                res = _("lima.table.voucher"); // Voucher
                break;
            case 4:
                res = _("lima.table.description"); //Description
                break;
            case 5:
                res = _("lima.table.letter"); //Letter
                break;
            case 6:
                res = _("lima.table.debit"); //Debit
                break;
            case 7:
                res = _("lima.table.credit"); //Credit
                break;
        }
        return res;
    }

    @Override
    public Object getValueAt(int row, int column) {
        Object result = null;
        if(cacheDataList != null) {
            Entry currentRow = cacheDataList.getListEntry().get(row);
            SimpleDateFormat simpleDateFormat
                = new SimpleDateFormat("dd MMMMM yyyy");
            
            switch (column) {
                case 0:
                    result = currentRow.getAccount().getAccountNumber();
                    break;
                case 1:
                    result = simpleDateFormat.
                            format(currentRow.getFinancialTransaction().getTransactionDate());
                    break;
                case 2:
                    if (currentRow.getFinancialTransaction().getEntryBook() != null){
                        result = currentRow.getFinancialTransaction().getEntryBook().getCode();
                    }
                    else {
                        result = null;
                    }
                    break;
                case 3:
                    result = currentRow.getVoucher();
                    break;
                case 4:
                    result = currentRow.getDescription();
                    break;
                case 5:
                    if (currentRow.getLetter() != null){
                        result = currentRow.getLetter().getCode();
                    }
                    else {
                        result = null;
                    }
                    break;
                case 6:
                    result = currentRow.getDebit() ? currentRow.getAmount() : 0;
                    break;
                case 7:
                    result = currentRow.getDebit() ? 0 : currentRow.getAmount();
                    break;
            }
        } 
        else {
            if (log.isDebugEnabled()) {
                log.debug("No Account selected skip table model update");
            }
        }

        return result;
    }


    @Override
    public boolean isCellEditable(int rowIndex, int columnIndex) {
        // Just read, no write
        return false;
    }
    
    public void refresh(ReportsDatas datasList){
        cacheDataList = datasList;
        fireTableDataChanged();
    }
    
}
